pub struct Route { /* private fields */ }Expand description
How to reach the same observation again.
The road is the callable entry point the door names, which needs no proc macro anywhere in the path.
Implementations