pub enum NoQuestions {}Expand description
The question roster of a kind that owes nothing beyond the universal questions.
Uninhabited, so it is its own answer as well as its own roster: there is no value here to ask about or to answer for.