pub enum ProjectionDisposition {
Generated,
NotRequested,
FeatureUnavailable,
TargetUnavailable,
}Expand description
The public readback of what happened to one possible recipe projection.
Variants
Generated
The role is selected and generated.
NotRequested
The caller did not request the role.
The facade feature posture does not carry the required harness owner.
The caller declared that the target plane is unavailable.
Implementations