EffectiveProjection

Struct EffectiveProjection 

pub struct EffectiveProjection { /* private fields */ }
The effective mechanical configuration of one generated projection.

Implementations

Source

impl EffectiveProjection

pub const fn role(&self) -> RecipeRole

Reads the selected role.

pub fn name(&self) -> Option<&str>

Reads the effective public spelling where this role declares one.

pub fn subject(&self) -> Option<&str>

Reads the informed structural subject selected for this projection.

pub const fn source(&self) -> LoweringSource

Reads where the effective value came from.

pub const fn exact_rust(&self) -> Option<&GeneratedTree>

Reads the exact caller-authored Rust that replaced this mechanical seat.

pub const fn dispatch_binding_tokens(&self) -> Option<&[GeneratedToken; 2]>

Reads the exact state and event binding tokens selected for an exact dispatch body.

pub fn dispatch_bindings(&self) -> Option<[&str; 2]>

Reads the state and event parameter bindings selected for an exact dispatch body.

pub const fn dispatch_subject_imports(&self) -> Option<[bool; 2]>

Reads whether an exact dispatch signature requires each transition vocabulary in scope.

pub fn relation_tables(&self) -> impl Iterator<Item = &RelationTableProjection>

Reads every selected relation-table surface in declaration order.