pub enum SelfRelationPosture {
Allowed,
Refusal,
}Expand description
Whether a member may relate to itself in a same-roster relation.
Variants
Implementations
Sourceimpl SelfRelationPosture
impl SelfRelationPosture
Sourcepub const fn requirement(
self,
) -> Option<StructuralRequirement<SelfRelationStanding>>
pub const fn requirement( self, ) -> Option<StructuralRequirement<SelfRelationStanding>>
The self-relation requirement expressed by this posture, when it constrains self relations.