StructuralRequirement

Struct StructuralRequirement 

pub struct StructuralRequirement<Answer> { /* private fields */ }
One caller-declared answer required of one independently computed structural answer.

Implementations

Source

impl<Answer> StructuralRequirement<Answer>

pub const fn stated(required: Answer) -> Self

States the exact answer one caller requires from one structural question.

pub const fn required(&self) -> &Answer

The answer the caller requires.

Source

impl<Answer: Eq> StructuralRequirement<Answer>

pub fn settle( self, observed: Answer, ) -> Result<Answer, StructuralMismatch<Answer>>

Settles one computed answer against this caller-declared requirement.

Errors

Returns both answers when the computed answer differs from the required answer.