pub enum AssemblyIssue {
RootsDisagree {
axis: CargoAxis,
stated: Identity<CapturedDeclaration>,
carried: Identity<CapturedDeclaration>,
},
DeclaredAxisRequiresStampedCargo,
CargoConsumedTwice {
source: ClosedExpansionId,
destination: Destination,
},
CargoReachesASecondDestination {
axis: CargoAxis,
destination: Destination,
},
CargoNotTheSourcesOwn {
source: ClosedExpansionId,
destination: Destination,
},
TwoFormsCarried,
StampedCargoAbsent {
form: DeliveryForm,
},
}Expand description
One way closed outputs do not compose into one carrier.
Variants
RootsDisagree
A carried terminal stands over another declaration.
Fields

stated: Identity<CapturedDeclaration>The stated declaration.

carried: Identity<CapturedDeclaration>The carried declaration.
DeclaredAxisRequiresStampedCargo
Opaque deferred cargo was offered for the stamped declaration axis.
CargoConsumedTwice
One delivery was consumed twice.
CargoReachesASecondDestination
Cargo reached an axis for another destination.
CargoNotTheSourcesOwn
The delivery did not prove the supplied cargo.
TwoFormsCarried
Both delivery forms were carried.
StampedCargoAbsent
A required stamped seat was absent.
Fields

form: DeliveryFormThe affected form.
Implementations
Sourceimpl AssemblyIssue
impl AssemblyIssue
Sourcepub fn canonical_bytes(&self) -> Vec<u8> ⓘ
pub fn canonical_bytes(&self) -> Vec<u8> ⓘ
Returns this issue’s canonical bytes.
Sourcepub fn encode_into(&self, into: &mut Vec<u8>)
pub fn encode_into(&self, into: &mut Vec<u8>)
Appends this issue’s canonical bytes.