pub struct BoundPath { /* private fields */ }Expand description
A rendered path rooted at a declared crate facing.
Implementations
Sourceimpl BoundPath
impl BoundPath
Sourcepub fn rooted(
facing: CrateFacing,
segments: Vec<String>,
) -> Result<Self, DeclarationError>
pub fn rooted( facing: CrateFacing, segments: Vec<String>, ) -> Result<Self, DeclarationError>
Declares a rooted item path.
Errors
Returns the identifier, empty, or magnitude refusal established by the input.
Sourcepub const fn facing(&self) -> CrateFacing
pub const fn facing(&self) -> CrateFacing
Reads the crate facing.