function_item

Function function_item 

pub fn function_item(
    signature: Vec<GeneratedToken>,
    body: Vec<GeneratedToken>,
) -> Result<Vec<GeneratedToken>, Overflow>
One function or method item from an exact signature and exact body.

Errors

Returns Overflow where the body outgrows the declared generated-token magnitude.