Route

Struct Route 

pub struct Route { /* private fields */ }
How to reach the same observation again.

The road is the callable entry point the door names, which needs no proc macro anywhere in the path.

Implementations

Source

impl Route

pub const fn entry(self) -> Identity<ServiceEntry>

The callable entry point that reaches this observation again.